Remove warning on ballot/any/all and pop/clz.
Since these are supported in HIP no reason to emit warnings.
This commit is contained in:
@@ -75,6 +75,7 @@ macro (make_hip_executable exe cpp)
|
||||
endif()
|
||||
endmacro()
|
||||
|
||||
|
||||
macro (make_test exe )
|
||||
string (REPLACE " " "" smush_args ${ARGN})
|
||||
set (testname ${exe}${smush_args}.tst)
|
||||
@@ -87,6 +88,16 @@ macro (make_test exe )
|
||||
endmacro()
|
||||
|
||||
|
||||
macro (make_hipify_test sourceFile )
|
||||
#string (REPLACE " " "" smush_args ${ARGN})
|
||||
set (testname ${sourceFile}${smush_args}.tst)
|
||||
|
||||
add_test (NAME ${testname}
|
||||
COMMAND ${HIP_PATH}/bin/hipify ${PROJECT_SOURCE_DIR}/${sourceFile} ${ARGN}
|
||||
)
|
||||
endmacro()
|
||||
|
||||
|
||||
macro (make_test_matches exe match_string)
|
||||
string (REPLACE " " "" smush_args ${ARGN})
|
||||
set (testname ${exe}${smush_args}.tst)
|
||||
@@ -133,3 +144,5 @@ make_test(hipGridLaunch " " )
|
||||
make_test(hipMemcpy " " )
|
||||
|
||||
make_test(hipHcc " " )
|
||||
|
||||
make_hipify_test(specialFunc.cu )
|
||||
|
||||
@@ -0,0 +1,11 @@
|
||||
//Test to ensure hipify runs correctly.
|
||||
// Hipify may report warnings for some missing/unsupported functions
|
||||
|
||||
void __global__
|
||||
test_kernel(float *A)
|
||||
{
|
||||
int tid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
|
||||
float a = __ballot(tid < 16);
|
||||
float b = __shfl(tid < 16);
|
||||
}
|
||||
Reference in New Issue
Block a user